@@ -5,7 +5,7 @@ class BackendSpec:
 
     tf_backends = ['local', 's3', 'remote']
 
-    def __init__(self, blueprint_id, aws_account_id=None, organization=None, dry_run=False, verbose=False):
+    def __init__(self, blueprint_id, s3_bucket=None, organization=None, dry_run=False, verbose=False):
         self.backend_type = 's3'
 
         # Enable dry run (skip backend configuration)
@@ -14,10 +14,13 @@ class BackendSpec:
         # Enable verbose logging
         self.verbose = verbose
 
+        # Blueprint home directory
+        self.blueprint_home = '.'
+
         # Blueprint identifier
         self.blueprint_id = blueprint_id
 
-        self.aws_account_id = aws_account_id
+        self.s3_bucket = s3_bucket
         self.organization = organization
 
     def run(self):
@@ -27,12 +30,12 @@ class BackendSpec:
         if self.backend_type == 's3':
             backend = """terraform {
   backend "s3" {
-    bucket = "%s-terraform-state"
+    bucket = "%s"
     dynamodb_table = "terraform-lock"
     key = "blueprint/%s/terraform.tfstate"
   }
 }
-            """ % (self.aws_account_id, self.blueprint_id)
+            """ % (self.s3_bucket, self.blueprint_id)
         elif self.backend_type == 'remote':
             backend = """terraform {
   backend "remote" {
@@ -52,4 +55,4 @@ class BackendSpec:
 """
 
         if not self.dry_run:
-            write_backend(self.blueprint_id, backend)
+            write_backend(self.blueprint_id, self.blueprint_home, backend)
